@@ -1,5 +1,5 @@
 // Copyright (c) 2015-2021 Patricio Cubillos and contributors.
-// MC3 is open-source software under the MIT license (see LICENSE).
+// mc3 is open-source software under the MIT license (see LICENSE).
 
 #include <Python.h>
 #define NPY_NO_DEPRECATED_API NPY_1_7_API_VERSION
@@ -88,7 +88,6 @@ static PyMethodDef _binarray_methods[] = {
     {NULL,           NULL,        0,            NULL}
 };
 
-#if PY_MAJOR_VERSION >= 3
 /* Module definition for Python 3.                                          */
 static struct PyModuleDef moduledef = {
     PyModuleDef_HEAD_INIT,
@@ -106,12 +105,3 @@ PyObject *PyInit__binarray (void) {
     return module;
 }
 
-#else
-/* When Python 2 imports a C module named 'X' it loads the module           */
-/* then looks for a method named "init"+X and calls it.                     */
-void init_binarray(void){
-    Py_InitModule3("_binarray", _binarray_methods, _binarraymod__doc__);
-    import_array();
-}
-#endif
-
